@@ -1,25 +1,28 @@
 #' @importFrom utils capture.output
-capture.print <- function(obj,comment = NA,...){
+#' @importFrom xfun upload_imgur
+capture.print <- function(obj, comment = NA,...){
   
   if(details_env$device){
     
-    if(details_env$imgur)
-      obj <- sprintf('![](%s)',imgur_upload(obj))
+    if(details_env$imgur){
+      imgur_res <- xfun::upload_imgur(obj, include_xml = TRUE)
+      obj <- sprintf('![](%s)', imgur_res$link)
+    }
     
   }else{
 
-    if(!inherits(obj,'character')){
+    if(!inherits(obj, 'character')){
       
-      obj <- utils::capture.output(print(obj,...))  
+      obj <- utils::capture.output(print(obj, ...))
       
     }
         
   }
   
   if(!is.na(comment))
-    obj <- paste0(comment,' ',obj)
+    obj <- paste0(comment, ' ', obj)
   
-  paste0(obj,collapse = '\n')
+  paste0(obj, collapse = '\n')
 }
 
 read_text <- function(text){
